(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[5744],{24354:function(e,n,r){(window.__NEXT_P=window.__NEXT_P||[]).push(["/data-discovery/detection/[resourceUrn]",function(){return r(38038)}])},38038:function(e,n,r){"use strict";r.r(n);var t=r(24246);r(27378);var c=r(65464),i=r(11032),s=r(37541),u=r(8339),o=r(38637),a=r(79620);n.default=()=>{let{resourceUrn:e,navigateToDetectionResults:n}=(0,o.Z)();return(0,t.jsxs)(c.Z,{title:"Data detection",mainProps:{padding:"0 40px 48px"},children:[(0,t.jsx)(s.Z,{breadcrumbs:[{title:"Data detection"}],children:(0,t.jsx)(u.Z,{parentLink:i.XY,resourceUrn:e,onPathClick:e=>n({resourceUrn:e})})}),(0,t.jsx)(a.Z,{resourceUrn:e})]})}}},function(e){e.O(0,[8033,6451,8540,4093,1734,2888,9774,179],function(){return e(e.s=24354)}),_N_E=e.O()}]);