(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[2158],{15786:function(e,n,i){(window.__NEXT_P=window.__NEXT_P||[]).push(["/consent/privacy-notices/new",function(){return i(54155)}])},54155:function(e,n,i){"use strict";i.r(n);var s=i(24246),t=i(69746),c=i(43124),a=i(73485),o=i(11032),d=i(26796);n.default=()=>(0,s.jsxs)(c.Z,{title:"New privacy notice",children:[(0,s.jsxs)(t.xuv,{mb:4,children:[(0,s.jsx)(a.Z,{backPath:o.IT}),(0,s.jsx)(t.X6q,{fontSize:"2xl",fontWeight:"semibold",mb:2,"data-testid":"header",children:"New privacy notice"})]}),(0,s.jsxs)(t.xuv,{width:{base:"100%",lg:"70%"},children:[(0,s.jsx)(t.xvT,{fontSize:"sm",mb:8,children:"Configure your privacy notice including consent mechanism, associated data uses and the locations in which this should be displayed to users."}),(0,s.jsx)(t.xuv,{"data-testid":"new-privacy-notice-page",children:(0,s.jsx)(d.Z,{})})]})]})}},function(e){e.O(0,[3662,4554,2866,5870,3528,1241,6796,2888,9774,179],function(){return e(e.s=15786)}),_N_E=e.O()}]);