(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3453],{35041:function(n,t,e){(window.__NEXT_P=window.__NEXT_P||[]).push(["/data-discovery/detection",function(){return e(67489)}])},67489:function(n,t,e){"use strict";e.r(t);var i=e(24246);e(27378);var a=e(65464),c=e(11032),r=e(37541),s=e(8339),u=e(79620);t.default=()=>(0,i.jsxs)(a.Z,{title:"Data detection",mainProps:{padding:"0 40px 48px"},children:[(0,i.jsx)(r.Z,{breadcrumbs:[{title:"Data detection"}],children:(0,i.jsx)(s.Z,{parentLink:c.XY})}),(0,i.jsx)(u.Z,{})]})}},function(n){n.O(0,[8033,6451,8540,4093,1734,2888,9774,179],function(){return n(n.s=35041)}),_N_E=n.O()}]);