(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[1285],{67643:function(e,n,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/consent/properties",function(){return t(54242)}])},54242:function(e,n,t){"use strict";t.r(n);var i=t(24246),s=t(69746),r=t(43124),o=t(5784);n.default=()=>(0,i.jsxs)(r.Z,{title:"Properties",children:[(0,i.jsxs)(i.Fragment,{children:[(0,i.jsx)(s.xuv,{mb:4,children:(0,i.jsx)(s.X6q,{fontSize:"2xl",fontWeight:"semibold",mb:2,"data-testid":"header",children:"Properties"})}),(0,i.jsx)(s.kCb,{children:(0,i.jsx)(s.xvT,{fontSize:"sm",mb:8,width:{base:"100%",lg:"60%"},children:"Review and manage your properties below. Properties are the locations you have configured for consent management such as a website or mobile app."})})]}),(0,i.jsx)(o.V,{})]})}},function(e){e.O(0,[8033,6451,8540,1316,2888,9774,179],function(){return e(e.s=67643)}),_N_E=e.O()}]);