(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[8161],{23321:function(e,t,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/properties/[id]",function(){return n(3770)}])},3770:function(e,t,n){"use strict";n.r(t);var r=n(24246),i=n(69746),s=n(86677),u=n(60136),d=n(43124),l=n(16781),o=n(96421),c=n(57353),a=n(43073);t.default=()=>{let e=(0,i.pmc)(),{id:t}=(0,s.useRouter)().query,{data:n}=(0,o.J6)(t),[p]=(0,o.f2)(),f=async t=>{let{id:n,messaging_templates:r,...i}=t,s=await p({id:n,property:i});if((0,a.D4)(s)){e((0,l.Vo)((0,u.e$)(s.error)));return}e((0,l.t5)("Property ".concat(t.name," updated successfully")))};return n?(0,r.jsxs)(d.Z,{title:n.name,children:[(0,r.jsx)(i.xuv,{display:"flex",alignItems:"center","data-testid":"header",children:(0,r.jsxs)(i.X6q,{fontSize:"2xl",fontWeight:"semibold",children:["Edit ",n.name]})}),(0,r.jsxs)(i.xuv,{maxWidth:"720px",pt:2,children:[(0,r.jsx)(i.xvT,{fontSize:"sm",children:"Edit your existing property here."}),(0,r.jsx)(c.Z,{property:n,handleSubmit:f})]})]}):null}}},function(e){e.O(0,[3528,6375,2888,9774,179],function(){return e(e.s=23321)}),_N_E=e.O()}]);