(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4648],{12037:function(i,e,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/consent/privacy-notices/[id]",function(){return n(14755)}])},14755:function(i,e,n){"use strict";n.r(e);var t=n(24246),s=n(69746),c=n(86677),a=n(43124),r=n(73485),d=n(11032),o=n(40793),u=n(26796);e.default=()=>{let i=(0,c.useRouter)(),e="";i.query.id&&(e=Array.isArray(i.query.id)?i.query.id[0]:i.query.id);let{data:n,isLoading:l}=(0,o._g)(e),{data:h}=(0,o.Wq)(e);return l?(0,t.jsx)(a.Z,{title:"Privacy notice",children:(0,t.jsx)(s.M5Y,{children:(0,t.jsx)(s.$jN,{})})}):n?(0,t.jsxs)(a.Z,{title:"Privacy notice ".concat(n.name),children:[(0,t.jsx)(r.Z,{backPath:d.IT}),(0,t.jsx)(s.X6q,{fontSize:"2xl",fontWeight:"semibold",mb:4,"data-testid":"header",children:n.name}),(0,t.jsxs)(s.xuv,{width:{base:"100%",lg:"70%"},children:[(0,t.jsx)(s.xvT,{fontSize:"sm",mb:8,children:"Configure your privacy notice including consent mechanism, associated data uses and the locations in which this should be displayed to users."}),(0,t.jsx)(s.xuv,{"data-testid":"privacy-notice-detail-page",children:(0,t.jsx)(u.Z,{privacyNotice:n,availableTranslations:h})})]})]}):(0,t.jsx)(a.Z,{title:"Privacy notice",children:(0,t.jsxs)(s.xvT,{children:["No privacy notice with id ",e," found."]})})}}},function(i){i.O(0,[3662,4554,2866,5870,3528,1241,6796,2888,9774,179],function(){return i(i.s=12037)}),_N_E=i.O()}]);