(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[1855],{89772:function(e,t,r){(window.__NEXT_P=window.__NEXT_P||[]).push(["/properties/add-property",function(){return r(61575)}])},61575:function(e,t,r){"use strict";r.r(t);var n=r(24246),s=r(69746),d=r(86677),i=r(60136),c=r(43124),o=r(11032),u=r(16781),a=r(96421),l=r(57353),p=r(43073);let h=()=>(0,n.jsx)(s.xuv,{display:"flex",alignItems:"center","data-testid":"header",children:(0,n.jsx)(s.X6q,{fontSize:"2xl",fontWeight:"semibold",children:"Add property"})});t.default=()=>{let e=(0,s.pmc)(),t=(0,d.useRouter)(),[r]=(0,a.dX)(),f=async n=>{let s=await r(n);if((0,p.D4)(s)){e((0,u.Vo)((0,i.e$)(s.error)));return}let d=s.data;e((0,u.t5)("Property ".concat(n.name," created successfully"))),t.push("".concat(o.ru,"/").concat(d.id))};return(0,n.jsxs)(c.Z,{title:"Add property",children:[(0,n.jsx)(h,{}),(0,n.jsxs)(s.xuv,{maxWidth:"720px",pt:2,children:[(0,n.jsx)(s.xvT,{fontSize:"sm",children:"Add new property to Fides here."}),(0,n.jsx)(l.Z,{handleSubmit:f})]})]})}}},function(e){e.O(0,[3528,6375,2888,9774,179],function(){return e(e.s=89772)}),_N_E=e.O()}]);