(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[1242],{29221:function(e,r,s){(window.__NEXT_P=window.__NEXT_P||[]).push(["/privacy-requests/configure",function(){return s(48566)}])},43124:function(e,r,s){"use strict";s.d(r,{Z:function(){return f}});var i=s(24246),n=s(69746),t=s(88038),o=s.n(t),a=s(86677);s(27378);var c=s(11596),u=s(72247),l=s(11032),d=()=>{let e=(0,a.useRouter)();return(0,i.jsx)(n.xuv,{bg:"gray.50",border:"1px solid",borderColor:"blue.400",borderRadius:"md",justifyContent:"space-between",p:5,mb:5,mt:5,children:(0,i.jsxs)(n.xuv,{children:[(0,i.jsxs)(n.Kqy,{direction:{base:"column",sm:"row"},justifyContent:"space-between",children:[(0,i.jsx)(n.xvT,{fontWeight:"semibold",children:"Configure your storage and messaging provider"}),(0,i.jsx)(n.wpx,{onClick:()=>{e.push(l.fz)},children:"Configure"})]}),(0,i.jsxs)(n.xvT,{children:["Before Fides can process your privacy requests we need two simple steps to configure your storage and email client."," "]})]})})},f=e=>{let{children:r,title:s,padded:t=!0,mainProps:l}=e,f=(0,c.hz)(),h=(0,a.useRouter)(),m="/privacy-requests"===h.pathname||"/datastore-connection"===h.pathname,g=!(f.flags.privacyRequestsConfiguration&&m),{data:p}=(0,u.JE)(void 0,{skip:g}),{data:x}=(0,u.PW)(void 0,{skip:g}),b=f.flags.privacyRequestsConfiguration&&(!p||!x)&&m;return(0,i.jsxs)(n.kCb,{"data-testid":s,direction:"column",h:"100vh",children:[(0,i.jsxs)(o(),{children:[(0,i.jsxs)("title",{children:["Fides Admin UI - ",s]}),(0,i.jsx)("meta",{name:"description",content:"Privacy Engineering Platform"}),(0,i.jsx)("link",{rel:"icon",href:"/favicon.ico"})]}),(0,i.jsxs)(n.kCb,{as:"main",direction:"column",py:t?6:0,px:t?10:0,h:t?"calc(100% - 48px)":"full",flex:1,minWidth:0,overflow:"auto",...l,children:[b?(0,i.jsx)(d,{}):null,r]})]})}},73485:function(e,r,s){"use strict";s.d(r,{R:function(){return c}});var i=s(24246),n=s(69746),t=s(79894),o=s.n(t),a=s(63662);let c=e=>{let{onClick:r,...s}=e;return(0,i.jsxs)(n.kCb,{alignItems:"center",mt:-4,mb:3,onClick:r,cursor:"pointer",...s,children:[(0,i.jsx)(n.wpx,{"aria-label":"Back",icon:(0,i.jsx)(n.Rpv,{}),className:"mr-2",size:"small"}),(0,i.jsx)(n.xvT,{as:"a",fontSize:"sm",fontWeight:"500",children:"Back"})]})};r.Z=e=>{let{backPath:r,...s}=e,t=(0,a.useRouter)();return(0,i.jsxs)(n.kCb,{alignItems:"center",mb:6,...s,children:[(0,i.jsx)(n.wpx,{onClick:()=>t.push(r),"aria-label":"Back",icon:(0,i.jsx)(n.Rpv,{}),className:"mr-2",size:"small"}),(0,i.jsx)(n.xvT,{as:o(),href:r,fontSize:"sm",fontWeight:"500",children:"Back"})]})}},48566:function(e,r,s){"use strict";s.r(r);var i=s(24246),n=s(69746),t=s(79894),o=s.n(t),a=s(43124),c=s(73485),u=s(11032);r.default=()=>(0,i.jsxs)(a.Z,{title:"Configure Privacy Requests",children:[(0,i.jsx)(c.Z,{backPath:u.Jw}),(0,i.jsx)(n.X6q,{mb:5,fontSize:"2xl",fontWeight:"semibold",children:"Configure your privacy requests"}),(0,i.jsxs)(n.xuv,{display:"flex",alignItems:"center",mb:5,"data-testid":"privacy-requests-configure",children:[(0,i.jsxs)(n.fGe,{p:"5",borderWidth:"1px",rounded:"md",borderColor:"gray.300",_hover:{borderColor:"complimentary.500",cursor:"pointer"},mr:5,minHeight:"100%",children:[(0,i.jsx)(n.X6q,{mb:2,size:"sm",children:(0,i.jsx)(n.AB5,{as:o(),href:"/privacy-requests/configure/messaging",children:"Configure messaging provider"})}),"Fides supports email (Mailgun & Twilio) and SMS (Twilio) server configurations for sending processing notices to privacy request subjects. Configure your settings here."]}),(0,i.jsxs)(n.fGe,{p:"5",borderWidth:"1px",rounded:"md",borderColor:"gray.300",_hover:{borderColor:"complimentary.500",cursor:"pointer"},minHeight:"100%",children:[(0,i.jsx)(n.X6q,{mb:2,size:"sm",children:(0,i.jsx)(n.AB5,{as:o(),href:"/privacy-requests/configure/storage",children:"Configure storage"})}),"The data produced by an access request will need to be uploaded to a storage destination (e.g. an S3 bucket) in order to be returned to the user. At least one storage destination must be configured to process access requests. Configure your settings here."]})]})]})}},function(e){e.O(0,[3662,2888,9774,179],function(){return e(e.s=29221)}),_N_E=e.O()}]);