(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[2447],{81327:function(e,n,s){(window.__NEXT_P=window.__NEXT_P||[]).push(["/settings/about",function(){return s(80599)}])},43124:function(e,n,s){"use strict";s.d(n,{Z:function(){return x}});var i=s(24246),r=s(69746),t=s(88038),o=s.n(t),l=s(86677);s(27378);var c=s(11596),a=s(72247),d=s(11032),u=()=>{let e=(0,l.useRouter)();return(0,i.jsx)(r.xuv,{bg:"gray.50",border:"1px solid",borderColor:"blue.400",borderRadius:"md",justifyContent:"space-between",p:5,mb:5,mt:5,children:(0,i.jsxs)(r.xuv,{children:[(0,i.jsxs)(r.Kqy,{direction:{base:"column",sm:"row"},justifyContent:"space-between",children:[(0,i.jsx)(r.xvT,{fontWeight:"semibold",children:"Configure your storage and messaging provider"}),(0,i.jsx)(r.wpx,{onClick:()=>{e.push(d.fz)},children:"Configure"})]}),(0,i.jsxs)(r.xvT,{children:["Before Fides can process your privacy requests we need two simple steps to configure your storage and email client."," "]})]})})},x=e=>{let{children:n,title:s,padded:t=!0,mainProps:d}=e,x=(0,c.hz)(),h=(0,l.useRouter)(),f="/privacy-requests"===h.pathname||"/datastore-connection"===h.pathname,m=!(x.flags.privacyRequestsConfiguration&&f),{data:j}=(0,a.JE)(void 0,{skip:m}),{data:p}=(0,a.PW)(void 0,{skip:m}),v=x.flags.privacyRequestsConfiguration&&(!j||!p)&&f;return(0,i.jsxs)(r.kCb,{"data-testid":s,direction:"column",h:"100vh",children:[(0,i.jsxs)(o(),{children:[(0,i.jsxs)("title",{children:["Fides Admin UI - ",s]}),(0,i.jsx)("meta",{name:"description",content:"Privacy Engineering Platform"}),(0,i.jsx)("link",{rel:"icon",href:"/favicon.ico"})]}),(0,i.jsxs)(r.kCb,{as:"main",direction:"column",py:t?6:0,px:t?10:0,h:t?"calc(100% - 48px)":"full",flex:1,minWidth:0,overflow:"auto",...d,children:[v?(0,i.jsx)(u,{}):null,n]})]})}},80599:function(e,n,s){"use strict";s.r(n),s.d(n,{default:function(){return d}});var i=s(24246),r=s(69746),t=s(11596),o=s(72573),l=s(94167);let c=e=>{let{flag:n,value:s,override:t}=e;return"boolean"!=typeof s?(0,i.jsxs)(i.Fragment,{children:[(0,i.jsx)(r.xvT,{fontSize:"sm",children:n}),(0,i.jsx)(r.xvT,{fontSize:"sm",children:s})]}):o.Ky[n].userCannotModify?null:(0,i.jsxs)(r.NIc,{display:"contents",children:[(0,i.jsx)(r.xuv,{justifySelf:"center",children:(0,i.jsx)(r.rAg,{id:"flag-".concat(n),checked:s,onChange:()=>t({flag:n,value:!s})})}),(0,i.jsx)(r.xuv,{children:(0,i.jsx)(r.lXp,{margin:0,fontSize:"sm",htmlFor:"flag-".concat(n),title:n,children:(0,l.Py)(n)})}),(0,i.jsx)(r.xuv,{children:(0,i.jsx)(r.xvT,{fontSize:"sm",children:o.Ky[n].description})})]})};var a=s(43124),d=()=>{let e=(0,t.hz)(),{flags:n,override:s,reset:l}=(0,o.Vb)();return(0,i.jsx)(a.Z,{title:"About Fides",children:(0,i.jsxs)(r.kCb,{direction:"column",gap:4,children:[(0,i.jsx)(r.X6q,{fontSize:"2xl",children:"About Fides"}),(0,i.jsxs)(r.xuv,{children:[(0,i.jsxs)(r.xvT,{as:"span",fontWeight:"bold",children:["Fides Core Version:"," "]}),(0,i.jsx)(r.xvT,{as:"pre",display:"inline",children:e.version})]}),e.plusVersion?(0,i.jsxs)(r.xuv,{children:[(0,i.jsxs)(r.xvT,{as:"span",fontWeight:"bold",children:["Fides Plus Version:"," "]}),(0,i.jsx)(r.xvT,{as:"pre",display:"inline",children:e.plusVersion})]}):null,(0,i.jsx)(r.izJ,{}),(0,i.jsxs)(r.kCb,{alignItems:"center",gap:4,children:[(0,i.jsx)(r.X6q,{as:"h2",fontSize:"xl",children:"Beta Features"}),(0,i.jsx)(r.wpx,{onClick:()=>l(),children:"Reset"})]}),(0,i.jsx)(r.rjZ,{gridTemplateColumns:"1fr 2fr 6fr",gridColumnGap:4,gridRowGap:2,alignItems:"center",children:o.R$.map(e=>(0,i.jsx)(c,{flag:e,value:n[e],override:s},e))}),(0,i.jsxs)(r.xuv,{children:[(0,i.jsxs)(r.xvT,{fontSize:"sm",children:["Please visit"," ",(0,i.jsx)(r.rUS,{color:"complimentary.500",href:"https://docs.ethyca.com",isExternal:!0,children:"docs.ethyca.com"})," ","for more information on these features."]}),(0,i.jsxs)(r.xvT,{fontSize:"sm",children:["For questions and feedback, please join us at"," ",(0,i.jsx)(r.rUS,{color:"complimentary.500",href:"https://fidescommunity.slack.com",isExternal:!0,children:"fidescommunity.slack.com"}),"."]})]})]})})}}},function(e){e.O(0,[2888,9774,179],function(){return e(e.s=81327)}),_N_E=e.O()}]);