(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[7322],{29303:function(e,n,i){(window.__NEXT_P=window.__NEXT_P||[]).push(["/properties",function(){return i(4771)}])},4771:function(e,n,i){"use strict";i.r(n);var t=i(24246),r=i(69746),s=i(43124),o=i(5784);n.default=()=>(0,t.jsxs)(s.Z,{title:"Properties",children:[(0,t.jsx)(r.xuv,{mb:4,children:(0,t.jsx)(r.X6q,{fontSize:"2xl",fontWeight:"semibold",mb:2,"data-testid":"header",children:"Properties"})}),(0,t.jsx)(r.kCb,{children:(0,t.jsx)(r.xvT,{fontSize:"sm",mb:8,width:{base:"100%",lg:"60%"},children:"Review and manage your properties below. Properties are the locations you have configured for consent management such as a website or mobile app."})}),(0,t.jsx)(o.V,{})]})}},function(e){e.O(0,[8033,6451,8540,1316,2888,9774,179],function(){return e(e.s=29303)}),_N_E=e.O()}]);